import cv2
import numpy as np
def process_mask(mask):
    # Find connected components
    num_labels, labels = cv2.connectedComponents(mask)
    
    # Count components (excluding background)
    num_objects = num_labels - 1
    
    # Find largest object
    largest_object_mask = np.zeros_like(mask)
    if num_objects > 0:
        # Get unique labels, excluding background (0)
        label_counts = [np.sum(labels == i) for i in range(1, num_labels)]
        largest_object_label = np.argmax(label_counts) + 1
        largest_object_mask = (labels == largest_object_label).astype(np.uint8) * 255
    
    return num_objects, largest_object_mask
def extract_largest_object(img,points_list):
    mask = np.zeros(img.shape[:2], dtype=np.uint8)
    for points in points_list:
        cv2.fillPoly(
            mask,
            [np.array(points, dtype=np.int32)],
            255
        )
    img_object, largest_object_mask = process_mask(mask)
    return largest_object_mask



from .aspect_ratio_minimized import calculate_aspect_ratio_rotated as aspect_ratio_min
from .find_area import find_area as pixel_area
from .screen_portion import screen_portion
from .perimeter import get_perimeter as perimeter
from .aspect_ratio import calculate_aspect_ratio as aspect_ratio
from .fill_mask_holes import fill_mask_holes
# from .invert_mask import invert_mask
from .sharpness import find_sharpness as max_sharpness
from .perimeter_coverage import perimeter_coverage as edge_portion
from .extract_largest_object import extract_largest_object
# from .unfilled_ratio import unfilled_ratio
from .validate_data import validate
from .centroid import centroid
__all__=['aspect_ratio_min','pixel_area','perimeter','aspect_ratio','fill_mask_holes','max_sharpness','edge_portion','extract_largest_object','screen_portion','centroid','validate']
